==> Qt6.2.4-WebAssembly-emscripten2.0.14-xLinux-x86_64-gcc8.5.0-20230613.tar.xz: Qt6.2.4-WebAssembly-emscripten2.0.14-xLinux-x86_64-gcc8.5.0/include/QtCore/qtcore-config.h <==
#define QT_FEATURE_clock_monotonic 1

#define QT_FEATURE_doubleconversion 1

#define QT_FEATURE_cxx11_future 1

#define QT_FEATURE_cxx17_filesystem 1

#define QT_FEATURE_eventfd -1

#define QT_FEATURE_glib -1

#define QT_FEATURE_inotify -1

#define QT_FEATURE_std_atomic64 1

#define QT_FEATURE_mimetype 1

#define QT_FEATURE_properties 1

#define QT_FEATURE_regularexpression 1

#define QT_FEATURE_sharedmemory -1

#define QT_FEATURE_shortcut 1

#define QT_FEATURE_systemsemaphore -1

#define QT_FEATURE_xmlstream 1

#define QT_FEATURE_xmlstreamreader 1

#define QT_FEATURE_xmlstreamwriter 1

#define QT_FEATURE_textdate 1

#define QT_FEATURE_datestring 1

#define QT_FEATURE_process 1

#define QT_FEATURE_processenvironment 1

#define QT_FEATURE_temporaryfile 1

#define QT_FEATURE_library 1

#define QT_FEATURE_settings 1

#define QT_FEATURE_filesystemwatcher 1

#define QT_FEATURE_filesystemiterator 1

#define QT_FEATURE_itemmodel 1

#define QT_FEATURE_proxymodel 1

#define QT_FEATURE_sortfilterproxymodel 1

#define QT_FEATURE_identityproxymodel 1

#define QT_FEATURE_transposeproxymodel 1

#define QT_FEATURE_concatenatetablesproxymodel 1

#define QT_FEATURE_stringlistmodel 1

#define QT_FEATURE_translation 1

#define QT_FEATURE_easingcurve 1

#define QT_FEATURE_animation 1

#define QT_FEATURE_gestures 1

#define QT_FEATURE_jalalicalendar 1

#define QT_FEATURE_islamiccivilcalendar 1

#define QT_FEATURE_timezone -1

#define QT_FEATURE_commandlineparser 1

#define QT_FEATURE_cborstreamreader 1

#define QT_FEATURE_cborstreamwriter 1

#define QT_NO_EVENTFD 1
#define QT_NO_GLIB 1
#define QT_NO_INOTIFY 1
#define QT_NO_SHAREDMEMORY 1
#define QT_NO_SYSTEMSEMAPHORE 1

==> Qt6.5.1-WebAssembly-emscripten3.1.25-xLinux-x86_64-gcc11.3.1-20230531.tar.xz: Qt6.5.1-WebAssembly-emscripten3.1.25-xLinux-x86_64-gcc11.3.1/include/QtCore/qtcore-config.h <==
#define QT_FEATURE_clock_monotonic 1

#define QT_FEATURE_doubleconversion 1

#define QT_FEATURE_cxx11_future 1

#define QT_FEATURE_cxx17_filesystem 1

#define QT_FEATURE_eventfd -1

#define QT_FEATURE_glib -1

#define QT_FEATURE_inotify -1

#define QT_FEATURE_std_atomic64 1

#define QT_FEATURE_mimetype 1

#define QT_FEATURE_regularexpression 1

#define QT_FEATURE_sharedmemory -1

#define QT_FEATURE_shortcut 1

#define QT_FEATURE_systemsemaphore -1

#define QT_FEATURE_xmlstream 1

#define QT_FEATURE_cpp_winrt -1

#define QT_FEATURE_xmlstreamreader 1

#define QT_FEATURE_xmlstreamwriter 1

#define QT_FEATURE_textdate 1

#define QT_FEATURE_datestring 1

#define QT_FEATURE_process -1

#define QT_FEATURE_processenvironment 1

#define QT_FEATURE_temporaryfile 1

#define QT_FEATURE_library 1

#define QT_FEATURE_settings 1

#define QT_FEATURE_filesystemwatcher 1

#define QT_FEATURE_filesystemiterator 1

#define QT_FEATURE_itemmodel 1

#define QT_FEATURE_proxymodel 1

#define QT_FEATURE_sortfilterproxymodel 1

#define QT_FEATURE_identityproxymodel 1

#define QT_FEATURE_transposeproxymodel 1

#define QT_FEATURE_concatenatetablesproxymodel 1

#define QT_FEATURE_stringlistmodel 1

#define QT_FEATURE_translation 1

#define QT_FEATURE_easingcurve 1

#define QT_FEATURE_animation 1

#define QT_FEATURE_gestures 1

#define QT_FEATURE_jalalicalendar 1

#define QT_FEATURE_islamiccivilcalendar 1

#define QT_FEATURE_timezone -1

#define QT_FEATURE_commandlineparser 1

#define QT_FEATURE_cborstreamreader 1

#define QT_FEATURE_cborstreamwriter 1

#define QT_FEATURE_permissions 1

#define QT_NO_EVENTFD 1
#define QT_NO_GLIB 1
#define QT_NO_INOTIFY 1
#define QT_NO_SHAREDMEMORY 1
#define QT_NO_SYSTEMSEMAPHORE 1
#define QT_NO_PROCESS 1
